rai\_toolbox.frozen
===================

.. currentmodule:: rai_toolbox

.. autoclass:: frozen

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~frozen.__init__
   
   

   
   
   